import enum
import os
from os.path import isfile
import socket

from bunq import ApiEnvironmentType
from bunq.sdk.context.api_context import ApiContext
from bunq.sdk.context.bunq_context import BunqContext
from bunq.sdk.model.generated.endpoint import User, UserLight, UserCompany, UserPerson

import AppMeta


class Bunq:
    def __init__(self, environment_type: ApiEnvironmentType, api_key: str):
        self.environment_type = environment_type
        self.api_key: str = api_key
        self.user = None
        self.setup_context()
        self.setup_current_user()

    def context_file_path(self):
        suffix = ""
        if self.environment_type == ApiEnvironmentType.SANDBOX:
            suffix = ".sandbox.bunq_ctx"
        elif self.environment_type == ApiEnvironmentType.PRODUCTION:
            suffix = ".production.bunq_ctx"
        return os.path.join(os.environ.get('BUNQ_CONTEXT_PREFIX') or ".", suffix)

    def setup_context(self):
        if isfile(self.context_file_path()):
            pass  # Config is already present
        else:
            ApiContext.create(
                self.environment_type,
                self.api_key,
                AppMeta.unique_app_identifier()
            ).save(self.context_file_path())

        api_context = ApiContext.restore(self.context_file_path())
        api_context.ensure_session_active()
        api_context.save(self.context_file_path())

        BunqContext.load_api_context(api_context)

    def setup_current_user(self):
        user = User.get().value.get_referenced_object()
        if (isinstance(user, UserPerson)
                or isinstance(user, UserCompany)
                or isinstance(user, UserLight)
        ):
            self.user = user

    def current_user(self):
        """
        :rtype: UserCompany|UserPerson
        """
        return self.user

    def update_context(self):
        BunqContext.api_context().save(self.context_file_path())
