import os
from wsgiref.simple_server import make_server

import falcon
from dotenv import load_dotenv

from bunq import ApiEnvironmentType

from Bunq import Bunq
from middleware.AuthMiddleware import AuthMiddleware

load_dotenv()

BUNQ = Bunq(
    ApiEnvironmentType.PRODUCTION if os.environ.get("BUNQ_ENVIRONMENT_TYPE") == "production" else ApiEnvironmentType.SANDBOX,
    os.environ.get("BUNQ_API_KEY"))


def main():
    print(f"Running for {BUNQ.current_user().display_name}...")

    app = falcon.App()
    app.add_middleware(AuthMiddleware())

    with make_server('', 8080, app) as server:
        print(f"Serving on :8080!")
        server.serve_forever()


if __name__ == '__main__':
    main()
